@@ -1,14 +1,10 @@
-
-hiddenimports = ['pkg_without_hook_for_pkg.sub1.sub11']
-
-NAME = 'pkg_without_hook_for_pkg.sub1'
-
-# self-test for this test-case:
 import PyInstaller.hooks
 import os
 # TODO For Python 3 replace this by importlib, imp is deprecated
 import imp
 
+NAME = 'pkg_without_hook_for_pkg.sub1'
+
 # 1. ensure self-test is working by searching for _this_ hook
 hookmodnm = 'hook-' + NAME
 searchpath = PyInstaller.hooks.__path__ + [os.path.dirname(__file__)]
@@ -18,9 +14,10 @@ assert imp.find_module(hookmodnm, searchpath) is not None, "Error in the hook's
 hookmodnm = 'hook-pkg_without_hook_for_pkg'
 try:
     imp.find_module(hookmodnm, searchpath)
-    raise Exception('Self-test of hook %s failed: hook for parent exists'
-                    % NAME)
+    raise Exception('Self-test of hook %s failed: hook for parent exists' % NAME)
 except ImportError as e:
     if e.name != hookmodnm:
-        raise Exception('Self-test of hook %s failed: hook for parent exists '
-                        'and has import errors.' % NAME)
+        raise Exception('Self-test of hook %s failed: hook for parent exists and has import errors.' % NAME)
+
+# The actual hook part
+hiddenimports = ['pkg_without_hook_for_pkg.sub1.sub11']
