@@ -8,8 +8,8 @@ import shutil
 import warnings
 from altgraph import Graph
 from PyInstaller.compat import is_win
+from PyInstaller.utils.tests import importorskip
 import textwrap
-from lxml import etree
 import pickle
 
 from importlib._bootstrap_external import SourceFileLoader, ExtensionFileLoader
@@ -508,7 +508,7 @@ class TestNode (unittest.TestCase):
         self.assertNoMethods(modulegraph.Package)
         self.assertNoMethods(modulegraph.Extension)
 
-        # AliasNode is basicly a clone of an existing node
+        # AliasNode is basically a clone of an existing node
         self.assertHasExactMethods(modulegraph.Script, '__init__', 'infoTuple')
         n1 = modulegraph.Node('n1')
         n1.packagepath = ['a', 'b']
@@ -630,7 +630,7 @@ class TestModuleGraph (unittest.TestCase):
         self.assertEqual(record, [])
 
         graph.implyNodeReference(n2, "n3")
-        n3 = graph.findNode('n3')
+        n3 = graph.find_node('n3')
         outs, ins = map(list, graph.get_edges(n2))
         self.assertEqual(outs, [n3])
         self.assertEqual(ins, [n1])
@@ -649,11 +649,11 @@ class TestModuleGraph (unittest.TestCase):
 
         graph = modulegraph.ModuleGraph()
         master = graph.createNode(modulegraph.Node, 'root')
-        m = graph.run_script(script, master)
+        m = graph.add_script(script, master)
         self.assertEqual(list(graph.get_edges(master)[0])[0], m)
         self.assertEqual(set(graph.get_edges(m)[0]), set([
-            graph.findNode('sys'),
-            graph.findNode('os'),
+            graph.find_node('sys'),
+            graph.find_node('os'),
         ]))
 
     @expectedFailure
@@ -679,7 +679,7 @@ class TestModuleGraph (unittest.TestCase):
         self.assertIsInstance(node, modulegraph.Package)
         parent = graph._determine_parent(node)
         self.assertEqual(parent.identifier, node.identifier)
-        self.assertEqual(parent, graph.findNode(node.identifier))
+        self.assertEqual(parent, graph.find_node(node.identifier))
         self.assertTrue(isinstance(parent, modulegraph.Package))
 
         # XXX: Might be a usecase for some odd code in determine_parent...
@@ -688,82 +688,17 @@ class TestModuleGraph (unittest.TestCase):
         #m = graph._determine_parent(node)
         #self.assertTrue(m is parent)
 
-        m = graph.findNode('xml')
+        m = graph.find_node('xml')
         self.assertEqual(graph._determine_parent(m), m)
 
-        m = graph.findNode('xml.dom')
-        self.assertEqual(graph._determine_parent(m), graph.findNode('xml.dom'))
+        m = graph.find_node('xml.dom')
+        self.assertEqual(graph._determine_parent(m), graph.find_node('xml.dom'))
 
 
     @expectedFailure
     def test_find_head_package(self):
         self.fail("find_head_package")
 
-    def test_load_tail(self):
-        # XXX: This test is dodgy!
-
-        class MockedModuleGraph(modulegraph.ModuleGraph):
-            def _safe_import_module(self, partname, fqname, parent):
-                record.append((partname, fqname, parent))
-                if partname == 'raises' or '.raises.' in fqname:
-                    # FIXME: original _load_tail returned a MissingModule if
-                    # _import_module did return None. PyInstaller changed this
-                    # in cae47e4f5b51a94ac3ceb5d093283ba0cc895589
-                    return self.createNode(modulegraph.MissingModule, fqname)
-                return modulegraph.Node(fqname)
-
-        graph = MockedModuleGraph()
-
-        record = []
-        root = modulegraph.Node('root')
-        m = graph._load_tail(root, '')
-        self.assertTrue(m is root)
-        self.assertEqual(record, [
-            ])
-
-        record = []
-        root = modulegraph.Node('root')
-        m = graph._load_tail(root, 'sub')
-        self.assertFalse(m is root)
-        self.assertEqual(record, [
-                ('sub', 'root.sub', root),
-            ])
-
-        record = []
-        root = modulegraph.Node('root')
-        m = graph._load_tail(root, 'sub.sub1')
-        self.assertFalse(m is root)
-        node = modulegraph.Node('root.sub')
-        self.assertEqual(record, [
-                ('sub', 'root.sub', root),
-                ('sub1', 'root.sub.sub1', node),
-            ])
-
-        record = []
-        root = modulegraph.Node('root')
-        m = graph._load_tail(root, 'sub.sub1.sub2')
-        self.assertFalse(m is root)
-        node = modulegraph.Node('root.sub')
-        node2 = modulegraph.Node('root.sub.sub1')
-        self.assertEqual(record, [
-                ('sub', 'root.sub', root),
-                ('sub1', 'root.sub.sub1', node),
-                ('sub2', 'root.sub.sub1.sub2', node2),
-            ])
-
-        n = graph._load_tail(root, 'raises')
-        self.assertIsInstance(n, modulegraph.MissingModule)
-        self.assertEqual(n.identifier, 'root.raises')
-
-        n = graph._load_tail(root, 'sub.raises')
-        self.assertIsInstance(n, modulegraph.MissingModule)
-        self.assertEqual(n.identifier, 'root.sub.raises')
-
-        n = graph._load_tail(root, 'sub.raises.sub')
-        self.assertIsInstance(n, modulegraph.MissingModule)
-        self.assertEqual(n.identifier, 'root.sub.raises.sub')
-
-
 
     @expectedFailure
     def test_ensure_fromlist(self):
@@ -940,7 +875,7 @@ class TestModuleGraph (unittest.TestCase):
             self.assertEqual(lines[1], 'Class           Name                      File')
             self.assertEqual(lines[2], '-----           ----                      ----')
             expected = []
-            for n in graph.flatten():
+            for n in graph.iter_graph():
                 if n.filename:
                     expected.append([type(n).__name__, n.identifier, n.filename])
                 else:
@@ -1032,7 +967,7 @@ class TestModuleGraph (unittest.TestCase):
         graph.addNode(n1)
         graph.addNode(n2)
 
-        graph.createReference(n1, n2)
+        graph.add_edge(n1, n2)
         outs, ins = map(list, graph.get_edges(n1))
         self.assertEqual(outs, [n2])
         self.assertEqual(ins, [])
@@ -1044,6 +979,7 @@ class TestModuleGraph (unittest.TestCase):
         self.assertIsInstance(e, int)
         self.assertEqual(graph.graph.edge_data(e), 'direct')
 
+    @importorskip('lxml')
     def test_create_xref(self):
         # XXX: This test is far from optimal, it just ensures
         # that all code is exercised to catch small bugs and
@@ -1051,9 +987,9 @@ class TestModuleGraph (unittest.TestCase):
         # works....
         graph = modulegraph.ModuleGraph()
         if __file__.endswith('.py'):
-            graph.run_script(__file__)
+            graph.add_script(__file__)
         else:
-            graph.run_script(__file__[:-1])
+            graph.add_script(__file__[:-1])
 
         graph.import_hook('os')
         graph.import_hook('xml.etree')
@@ -1064,6 +1000,7 @@ class TestModuleGraph (unittest.TestCase):
 
         data = fp.getvalue()
         # Don't tolerate any HTML `parsing errors <https://lxml.de/parsing.html#parser-options>`_.
+        from lxml import etree
         parser = etree.HTMLParser(recover=False)
         tree = etree.parse(StringIO(data), parser)
         assert tree is not None
@@ -1077,9 +1014,9 @@ class TestModuleGraph (unittest.TestCase):
         # works....
         graph = modulegraph.ModuleGraph()
         if __file__.endswith('.py'):
-            graph.run_script(__file__)
+            graph.add_script(__file__)
         else:
-            graph.run_script(__file__[:-1])
+            graph.add_script(__file__[:-1])
         graph.import_hook('os')
         graph.import_hook('xml.etree')
         graph.import_hook('unittest')
@@ -1093,7 +1030,7 @@ class TestModuleGraph (unittest.TestCase):
         list(graph.itergraphreport())
 
         # XXX: platpackages isn't implemented, and is undocumented hence
-        # it is unclear what this is inteded to be...
+        # it is unclear what this is intended to be...
         #list(graph.itergraphreport(flatpackages=...))
 
 
